'use client'

import { useEffect, useState } from 'react';
import FHIR from 'fhirclient';

export default function Callback() {
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    const params = new URLSearchParams(window.location.search);
    console.log('Callback URL parameters:', Object.fromEntries(params.entries()));

    FHIR.oauth2.ready()
      .then((client) => {
        console.log('SMART auth successful, redirecting...');
        window.location.href = '/';
      })
      .catch((err) => {
        console.error('SMART auth error:', err);
        setError(err.message || 'Authentication failed');
      });
  }, []);

  if (error) {
    return (
      <div className="p-4">
        <div className="bg-red-50 text-red-700 p-4 rounded">
          Authentication Error: {error}
        </div>
      </div>
    );
  }

  return (
    <div className="p-4">
      <div className="animate-pulse">
        <div className="h-4 bg-gray-200 rounded w-3/4"></div>
        <div className="space-y-3 mt-4">
          <div className="h-4 bg-gray-200 rounded"></div>
          <div className="h-4 bg-gray-200 rounded w-5/6"></div>
        </div>
      </div>
    </div>
  );
}